@@ -142,6 +142,24 @@ trans_delete(struct trans *self)
     g_free(self);
 }
 
+/*****************************************************************************/
+void
+trans_delete_from_child(struct trans *self)
+{
+    if (self == 0)
+    {
+        return;
+    }
+
+    if (self->listen_filename != 0)
+    {
+        g_free(self->listen_filename);
+        self->listen_filename = 0;
+    }
+
+    trans_delete(self);
+}
+
 /*****************************************************************************/
 int
 trans_get_wait_objs(struct trans *self, tbus *objs, int *count)
@@ -831,6 +849,26 @@ trans_listen_address(struct trans *self, char *port, const char *address)
             }
         }
     }
+    else if (self->mode == TRANS_MODE_VSOCK) /* vsock socket */
+    {
+        self->sck = g_sck_vsock_socket();
+        if (self->sck < 0)
+        {
+            return 1;
+        }
+
+        g_tcp_set_non_blocking(self->sck);
+
+        if (g_sck_vsock_bind(self->sck, port) == 0)
+        {
+            if (g_tcp_listen(self->sck) == 0)
+            {
+                self->status = TRANS_STATUS_UP; /* ok */
+                self->type1 = TRANS_TYPE_LISTENER; /* listener */
+                return 0;
+            }
+        }
+    }
 
     return 1;
 }
