@@ -1278,6 +1278,16 @@ segfault_signal_handler(int sig)
     exit(0);
 }
 
+/*****************************************************************************/
+static void
+x_server_fatal_handler(void)
+{
+    LOGM((LOG_LEVEL_INFO, "xserver_fatal_handler: entered......."));
+    /* At this point the X server has gone away. Dont make any X calls. */
+    xfuse_deinit();
+    exit(0);
+}
+
 /*****************************************************************************/
 static int
 get_display_num_from_display(char *display_text)
@@ -1451,7 +1461,8 @@ get_log_level(const char* level_str, enum logLevels default_level)
         "LOG_LEVEL_ERROR",
         "LOG_LEVEL_WARNING",
         "LOG_LEVEL_INFO",
-        "LOG_LEVEL_DEBUG"
+        "LOG_LEVEL_DEBUG",
+        "LOG_LEVEL_TRACE"
     };
     unsigned int i;
 
@@ -1575,6 +1586,9 @@ main(int argc, char **argv)
     g_signal_child_stop(child_signal_handler); /* SIGCHLD */
     g_signal_segfault(segfault_signal_handler);
 
+    /* Cater for the X server exiting unexpectedly */
+    xcommon_set_x_server_fatal_handler(x_server_fatal_handler);
+
     LOGM((LOG_LEVEL_INFO, "main: DISPLAY env var set to %s", display_text));
 
     if (g_display_num == 0)
