@@ -42,7 +42,7 @@ struct xrdp_mod
                    long param3, long param4);
   int (*mod_signal)(struct xrdp_mod* v);
   int (*mod_end)(struct xrdp_mod* v);
-  int (*mod_set_param)(struct xrdp_mod* v, const char *name, char* value);
+  int (*mod_set_param)(struct xrdp_mod *v, const char *name, const char *value);
   int (*mod_session_change)(struct xrdp_mod* v, int, int);
   int (*mod_get_wait_objs)(struct xrdp_mod* v, tbus* read_objs, int* rcount,
                            tbus* write_objs, int* wcount, int* timeout);
@@ -146,7 +146,9 @@ struct xrdp_mod
                             int num_crects, short *crects,
                             char *data, int width, int height,
                             int flags, int frame_id);
-  tintptr server_dumby[100 - 43]; /* align, 100 minus the number of server
+  int (*server_session_info)(struct xrdp_mod* v, const char *data,
+                             int data_bytes);
+  tintptr server_dumby[100 - 44]; /* align, 100 minus the number of server
                                      functions above */
   /* common */
   tintptr handle; /* pointer to self as int */
@@ -494,9 +496,7 @@ struct xrdp_bitmap
 #define DEFAULT_ELEMENT_TOP   35
 #define DEFAULT_BUTTON_W      60
 #define DEFAULT_BUTTON_H      23
-#define DEFAULT_COMBO_W       210
 #define DEFAULT_COMBO_H       21
-#define DEFAULT_EDIT_W        210
 #define DEFAULT_EDIT_H        21
 #define DEFAULT_WND_LOGIN_W   425
 #define DEFAULT_WND_LOGIN_H   475
